<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>За межами оглядача тенет також є життя!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Версія %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Ліцензія належить: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 — вільне проґрамне забезпечення, але на його розробку було затрачено коштовний час.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Будь ласка, &lt;a href=&apos;%1&apos;&gt;внесіть пожертву,&lt;/a&gt; аби підтримати подальший розвиток %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Перекласти %1 Вашою рідною мовою за допомогою %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Розробник піктоґрам %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Випущено за &lt;a href=&apos;%1&apos;&gt;Загальною громадською ліцензією GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрити</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Про проґраму</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Уведіть дані Вашої ліцензії</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Email:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Код:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>	
Ліцензуйте %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Пробний період вичерпано.</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>Повна версія дозволяє дивитися видиво без перерв.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Проґраму буде заблоковано через %1 днів, якщо Ви не придбаєте ліцензію.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>При купівлі повної версії, Ви, також, надаєте підтримку важкій роботі, яка була задіяна під час створення %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Демонстрація</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Увести ліцензію</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Придбати ліцензію</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Завантажити</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>За %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Усі видива</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Не переглянуті видива</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Назва</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Нещодавно оновлені</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Нещодавно додані</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Нещодавно переглянуті</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Найбільш переглядаюче</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Сортувати за</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Позначити все переглянутим</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Показати оновлені</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>У Вас немає підписок. Використовуйте символ зірочки, аби підписуватися на канали.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Усі видива</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Не переглянуті видива</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Позначити як переглянуте</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Відмовитися від підписки</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Наразі оновлень підписок немає.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Тільки що</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 переглядів</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>байтів</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>КБ</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>МБ</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>байтів/сек</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>КБ/сек</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>МБ/сек</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>секунд</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>хвилин</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>залишилося %4 %5</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 завантажений до %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Завантаження завершено</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Змінити теку для завантаження...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Оберіть теку для завантаження</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Теку завантаження змінено.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Поточні завантаження буде, як і раніше, збережено у попередньому місці.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Завантажується до %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Завантаження</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>Виконуваний файл було пошкоджено, може бути, вірус.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 не запущено. Спробуйте встановити ще раз.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Перевстановити</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Грати</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Грати/Призупинити</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Зупинити після завершення поточного</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Наступний трек</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Попередній трек</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Збільшити гучність</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Зменшити гучність</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Приглушити</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Перемотати вперед</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Перемотати назад</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Шукати</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Знайти видива та канали за ключовими словами</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Переглянути</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Оглянути видива за катеґоріями</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Підписки</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Підписки на канали</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Влаштовуйтесь якнайзручніше</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Вікно</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Згорнути</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Зупинити</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Зупинити відтворення та перейти до вікна пошуку</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>По&amp;передній</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Повернутися до попереднього треку</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>П&amp;ропустити</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Перейти до наступного видива</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Грати</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Відновити відтворення</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Повноекранний режим</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Перейти до повноекранного режиму</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>Компак&amp;тний режим</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Сховати перелік та панель інструментів</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Від&amp;крити сторінку YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Відкрити сторінку YouTube та призупинити відтворення видива</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Копіювати &amp;посилання на YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Скопіювати YouTube посилання поточного видива до буферу</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Копіювати посилання на ви&amp;диво потік</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Скопіювати посилання поточного видива до буферу</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Знайти &amp;фраґменти видива</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Знайти інші частини видива, сподіваюся, у правильному порядку</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Вилучити</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Вилучити обрані видива з переліку</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>До&amp;гори</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Перемістити обране видиво догори у переліку</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Дони&amp;зу</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Перемістити обране видиво донизу в переліку</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>О&amp;чистити останні пошукові запити</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Очистити історію пошуку (зміни незворотні).</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Вийти</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Бувайте</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Веб-сайт</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 у мережі</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Підтрима&amp;йте проєкт</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Будь ласка, підтримайте подальший розвиток %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Про проґраму</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Інформація про %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Шукати</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Приглушити гучність</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>&amp;Почати відтворення самотужки</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Почати відтворення видива самотужки</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Завантаження</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Показати деталі про видива, що завантажуються</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Завантажити</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Завантажити це видиво</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>Зробити &amp;Зняток</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Підписатися на канал</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Поділитися поточним видивом за допомогою %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;Email</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрити</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Згори всіх вікон</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>Зу&amp;пинити після цього видиво</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>По&amp;відомити про помилку</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Уточнити пошук...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Більше...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>Схо&amp;жі видива</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Дивитися видива, пов’язані з поточним</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Відкрити в &amp;оглядачі тенет...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>Обмежений режим</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>Приховати відео, які можуть містити небажаний контент</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Подобається %1? Оцініть !</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Придбати %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Застосунок</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Відтворення</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Перелік відтворення</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Видиво</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Поділитися</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Переглянути</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Довідка</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Натисніть %1, аби приглушити гучність, та %2, щоб її відновити</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Оберіть своє місцерозташування</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Відкриття %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Триває завантаження, бажаєте закрити %1?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Якщо закрити %1 негайно, усі завантаження буде скасовано.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Скасувати та закрити</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Дочекатися завершення</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Помилка: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Призупинити</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Призупинити відтворення</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Завантажити...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Вийти з &amp;повноекранного режиму</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Залишилося часу: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Гучність %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Гучність приглушено</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Гучність відновлено</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Режим чіткості видива %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Ваша приватність тепер у безпеці</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Завантаження завершено</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 версія %2 доступна.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Нагадати мені пізніше</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Оновлення</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Тепер Ви можете використовувати YouTube посилання на видиво у зовнішній проґрамі</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Тепер Ви можете використовувати посилання на видиво у зовнішній проґрамі</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Посилання буде дійсне лише протягом обмеженого часу.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Завантаження %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>з</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>частина</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>епізод</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Надіслати з %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Відписатися %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Підписуватися на %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Відписані від %1</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>Підписані на %1</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Доступна нова версія %1!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 доступна. Ви маєте %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Бажаєте завантажити це зараз?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Пропустити цю версію</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Нагадати пізніше</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Встановити оновлення</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Вставити</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation>Вибрати відео</translation>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 з %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Підготовка</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Невдача</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Виконано</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Зупинено</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Зупинити завантаження</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Відтворити у %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Перейти до теки з видивами</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Завантажити заново</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Наступні %1 </translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Нічого не знайдено</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Більше немає</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Сортувати за</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Релевантністю</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Датою</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Числом переглядів</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Рейтинґом</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>У будь-який час</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Сьогодні</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 днів</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 днів</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Тривалістю</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Усі</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Короткі</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Середні</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Довгі</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Коротші за 4 хвилини</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Між 4 та 20 хвилинами</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Довші, аніж 20 хвилин</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Якість</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>Висока роздільна здатність</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p або більше</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Шукати</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Ласкаво просимо до &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>аби розпочати перегляд.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>запит</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Уведіть</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Нещодавній пошук</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Останні канали</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Отримати повну версію</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>Н&amp;азад</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Вперед</translation>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Уперед до %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Назад до %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Уточнити пошук</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Можливо, Ви мали на увазі: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Змінити теку для завантаження...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Зняток збережено в %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Місцезнаходження знятків змінено.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Найпопулярніші</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Завантаження оновлення...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Завантаження %1...</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Алжир</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Аргентина</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Австралія</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Бельґія</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Бразилія</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Канада</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Чилі</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Колумбія</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Чехія</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Єгипет</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Франція</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Німеччина</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ґана</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Ґреція</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Гонконґ</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Угорщина</translation>
    </message>
    <message>
        <source>India</source>
        <translation>Індія</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Індонезія</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Ірландія</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Ізраїль</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Італія</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Японія</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Йорданія</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Кенія</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Малайзія</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Мексика</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Марокко</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Нідерланди</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Нова Зеландія</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Ніґерія</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Перу</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Філіппіни</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Польща</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Російська Федерація</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Саудівська Аравія</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Синґапур</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>ПАР</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Республіка Корея</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Іспанія</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Швеція</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Тайвань</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Туніс</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Туреччина</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Уґанда</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>ОАЕ</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Великобританія</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Ємен</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Світовий</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Не вдалося отримати видиво потік для %1</translation>
    </message>
</context>
</TS>